Change Log
==========

[next] - TBA
------------
* ...

[0.2.0] - 2021-03-29
--------------------
##### Enhancements
* Kaplan-Meier Plot icon ([#11](../../pull/11))
* owkaplanmeier: enable widget report, add description ([#12](../../pull/12))
* owkaplanmeier: change the symbol of censored data ([#13](../../pull/13))
* owkaplanmeier: add more information to the plot legend ([#14](../../pull/14))


[0.1.0] - 2021-01-12
--------------------
##### Enhancements
* New widget: Kaplan-Meier Plot



[next]: https://github.com/biolab/orange3-survival-analysis/compare/0.2.0...master
[0.2.0]: https://github.com/biolab/orange3-survival-analysis/compare/0.1.0...0.2.0
[0.1.0]: https://github.com/biolab/orange3-survival-analysis/compare/20b2bd8ea02876eb9cad3925e0954054da2690de...0.1.0
